package internalWindows;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import mapObjects.*;

/**
 * This class represent an internal frame used to create a new map.
 * @author Fredrik Stigsson
 *
 */
public class CreateNewMapFrame extends InternalFrame implements ActionListener
{
	
	//*********************************************************************************
	// Class variables
	//*********************************************************************************
	private static final long serialVersionUID = -2160393215382195242L;

	//*********************************************************************************
	// Instance variables
	//*********************************************************************************
	private Container mainFrameDesktop;
	private JLabel lblImagePath;
	private JLabel lblTileWidth;
	private JLabel lblTileHeight;
	private JLabel lblMapWidth;
	private JLabel lblMapHeight;
	private JTextField txtImagePath;
	private JTextField txtTileWidth;
	private JTextField txtTileHeight;
	private JTextField txtMapWidth;
	private JTextField txtMapHeight;
	
	//*********************************************************************************
	// Constructors
	//*********************************************************************************
	/**
	 * Create a new frame to create a new map.
	 */
	public CreateNewMapFrame(Container mainFrameDesktop)
	{
		// Call the constructor in the base class
		super("Create a new map", new Dimension(400, 300), new Point(100,100));
		
		// Set values for instance variables
		this.mainFrameDesktop = mainFrameDesktop;
		
		// Fill the internal frame with content.
		fillInternalFrame();
			
	} // End of the constructor
	
	//*********************************************************************************
	// Methods
	//*********************************************************************************
	/**
	 * Add content to the internal frame.
	 */
	private void fillInternalFrame()
	{
		// Create panels
		JPanel topPanel = new JPanel(new GridLayout(6,2, 0, 5));
		JPanel buttonPanel = new JPanel(new FlowLayout(50,10,5));
		
		// Set borders for panels
		topPanel.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
		
		// Create labels
		this.lblImagePath = new JLabel("Path to tilemap image: ");
		this.lblTileWidth = new JLabel("Tile width in pixels: ");
		this.lblTileHeight = new JLabel("Tile height in pixels: ");
		this.lblMapWidth = new JLabel("Mapwidth in number of tiles: ");
		this.lblMapHeight = new JLabel("Mapheight in number of tiles: ");
		
		// Create text fields
		this.txtImagePath = new JTextField();
		this.txtTileWidth = new JTextField();
		this.txtTileHeight = new JTextField();
		this.txtMapWidth = new JTextField();
		this.txtMapHeight = new JTextField();
		
		// Create buttons
		JButton btnUploadDirectory = new JButton("Select a image");
		JButton btnSave = new JButton("Ok");
		JButton btnCancel = new JButton("Cancel");
		
		// Add controls to the top panel.
		topPanel.add(this.lblImagePath);
		topPanel.add(new JLabel(""));
		topPanel.add(this.txtImagePath);
		topPanel.add(btnUploadDirectory);
		topPanel.add(this.lblTileWidth);
		topPanel.add(this.txtTileWidth);
		topPanel.add(this.lblTileHeight);
		topPanel.add(this.txtTileHeight);
		topPanel.add(this.lblMapWidth);
		topPanel.add(this.txtMapWidth);
		topPanel.add(this.lblMapHeight);
		topPanel.add(this.txtMapHeight);
		
		// Add controls to the button panel
		buttonPanel.add(btnSave);
		buttonPanel.add(btnCancel);
		
		// Add action listeners for buttons.
		btnUploadDirectory.addActionListener(this);
		btnSave.addActionListener(this);
		btnCancel.addActionListener(this);
		
		// Add panels to the content pane
		this.frameContentPane.add(topPanel, BorderLayout.NORTH);
		this.frameContentPane.add(buttonPanel, BorderLayout.SOUTH);

	} // End of the fillInternalFrame method
	
	//*********************************************************************************
	// Events
	//*********************************************************************************
	/**
	 * Handles click events for buttons.
	 * @param An ActionEvent denoted as e
	 */
	public void actionPerformed(ActionEvent e)
	{
		// Get the action command.
		String actionCommand = e.getActionCommand();
		
		// Do different actions based on the action command.
		if(actionCommand.equalsIgnoreCase("Select a image"))
		{
			// Create a new file chooser
			JFileChooser chooseDirectory = new JFileChooser("./images");
			
			// Get the choice option as an int32.
			int choice = chooseDirectory.showOpenDialog(this);
			
			// Get the selected directory.
			if (choice == JFileChooser.APPROVE_OPTION)
			{
				// Set the image path for the text box.
				this.txtImagePath.setText(chooseDirectory.getSelectedFile().toString());
			}
		}
		else if(actionCommand.equalsIgnoreCase("Ok"))
		{
			// Create a new map object
			Map2D newMap = new Map2D(this.txtImagePath.getText(), Short.parseShort(this.txtTileWidth.getText()), Short.parseShort(this.txtTileHeight.getText()), 
					Short.parseShort(this.txtMapWidth.getText()), Short.parseShort(this.txtMapHeight.getText()));
			
			// Close all open map editor frames
			Component[] internalFrames = mainFrameDesktop.getComponents();
			for(Component comp : internalFrames)
			{
				if(comp instanceof MapEditorFrame)
				{
					MapEditorFrame mapFrame = (MapEditorFrame)comp;
					mapFrame.dispose();
				}
			}

			// Create a new map editor frame
			MapEditorFrame internalFrame = new MapEditorFrame(newMap, mainFrameDesktop.getSize());
			
			// Add the internal frame to the desktop pane of the main frame
			mainFrameDesktop.add(internalFrame);
			
			// Set the frame as visible before it is added to the desktopPane.
			internalFrame.setVisible(true);
			
			// Dispose of this frame.
			this.dispose();

		}
		else if(actionCommand.equalsIgnoreCase("Cancel"))
		{
			this.dispose();
		}
		
	} // End of the actionPerformed method

} // End of the class
