package internalWindows;

import java.awt.*;
import javax.swing.*;

/**
 * This class is the superclass for internal frames, it includes properties that are common
 * to all internal frames
 * @author Fredrik Stigsson
 *
 */
public class InternalFrame extends JInternalFrame 
{
	//*********************************************************************************
	// Class variables
	//*********************************************************************************
	private static final long serialVersionUID = 2488652320502266644L;
	
	//*********************************************************************************
	// Instance variables
	//*********************************************************************************
	public Container frameContentPane;
	
	//*********************************************************************************
	// Constructors
	//*********************************************************************************
	/**
	 * Create a new internal frame with a specified name, size and location. The default
	 * close operation is also set and a contentPane is created.
	 * @param frameName is the name for the frame
	 * @param size is the size of the window
	 * @param location is the upper coordinate for the location of the window.
	 */
	public InternalFrame(String frameName, Dimension size, Point location)
	{
		
		// Call the constructor in the base class and set properties for the frame.
		super(frameName, true, true, false, true);
		
		// Set content pane and logic
		this.frameContentPane = this.getContentPane();
		
		// Set the size of the frame.
		this.setSize(size);
		
		// Set the location of the frame.
		this.setLocation(location.x, location.y);

		// Set the layout for the frame.
		this.setLayout(new BorderLayout(0,0));
		
		// Set the default close operation
		this.setDefaultCloseOperation(DISPOSE_ON_CLOSE);
		
	} // End of the constructor
	
	public void paintComponent(Graphics g)
	{
		super.paintComponent(g);
	}
	
} // End of the class
