package mapObjects;

import java.io.*;

import org.simpleframework.xml.*;

/**
 * This class represent a 2D map that is filled with tiles.
 * @author Fredrik Stigsson
 *
 */
@Root(name="Map2D")
public class Map2D implements Serializable
{
	//*********************************************************************************
	// Class variables
	//*********************************************************************************
	@Transient
	private static final long serialVersionUID = 5503996754387855034L;
	
	//*********************************************************************************
	// Instance variables
	//*********************************************************************************
	@Element
	public String imagePath;
	@Element
	public short tileWidth;
	@Element
	public short tileHeight;
	@Element
	public short mapWidth;
	@Element
	public short mapHeight;
	@ElementArray
	public Short[][] tiles;
	
	//*********************************************************************************
	// Constructors
	//*********************************************************************************
	/**
	 * Create a new map with predefined properties
	 * @param imagePath
	 * @param tileWidth
	 * @param tileHeight
	 * @param mapWidth
	 * @param mapHeight
	 */
	public Map2D(String imagePath, short tileWidth, short tileHeight, short mapWidth, short mapHeight)
	{
		// Set values for instance variables
		this.imagePath = imagePath;
		this.tileWidth = tileWidth;
		this.tileHeight = tileHeight;
		this.mapWidth = mapWidth;
		this.mapHeight = mapHeight;
		
		// Create the 2D list with tiles
		this.tiles = new Short[mapHeight][mapWidth];

		// Create a short value for each tile in the list.
		for(int y = 0; y < mapHeight; y++)
		{
			for(int x = 0; x < mapWidth; x++)
			{
				this.tiles[y][x] = 0;
			}
		}
		
	} // End of the parameterized constructor
	
	/**
	 * Default constructor
	 */
	public Map2D() 
	{
		this.imagePath = "Unknown";
		this.tileWidth = 0;
		this.tileHeight = 0;
		this.mapWidth = 0;
		this.mapHeight = 0;
		this.tiles = new Short[0][0];
		
	} // End of the default constructor.
	
} // End of the class
